import{S as i,i as _,s as f,R as u,f as c,b as m,t as r,c as b,N as g,O as d,P as h,v as p,w,e as k}from"./index.cab033fe.js";function y(n){let s,a;const o=n[2].default,t=u(o,n,n[1],null);return{c(){s=c("span"),t&&t.c(),m(s,"class","text-gray-600 text-[0.855rem] mb-2 block dark:text-gray-200 relative z-40"),r(s,"sr-only",!n[0])},m(e,l){b(e,s,l),t&&t.m(s,null),a=!0},p(e,[l]){t&&t.p&&(!a||l&2)&&g(t,o,e,e[1],a?h(o,e[1],l,null):d(e[1]),null),l&1&&r(s,"sr-only",!e[0])},i(e){a||(p(t,e),a=!0)},o(e){w(t,e),a=!1},d(e){e&&k(s),t&&t.d(e)}}}function v(n,s,a){let{$$slots:o={},$$scope:t}=s,{show_label:e=!0}=s;return n.$$set=l=>{"show_label"in l&&a(0,e=l.show_label),"$$scope"in l&&a(1,t=l.$$scope)},[e,t,o]}class S extends i{constructor(s){super(),_(this,s,v,y,f,{show_label:0})}}export{S as B};
